@@ -42,7 +42,7 @@
 #include "yelp-man.h"
 
 struct TreeNode {
-	char *name;
+	char  *name;
 
 	GList *tree_nodes;
 
@@ -50,24 +50,28 @@ struct TreeNode {
 };
 
 struct TreeData {
-	char *name;
+	char            *name;
 	struct TreeData *children;
-	char *section;
+	char            *section;
 };
 
+static gboolean  any_man_pages = FALSE;
+static GList    *man_index = NULL;
+
 /* Caller must free this */
 static char *
 extract_secnum_from_filename (const char *filename)
 {
 	char *end_string = NULL;
 	char *start;
-	int len;
+	int   len;
 
 #ifdef HAVE_LIBBZ2
 	end_string =  g_strrstr (filename, ".bz2");
 #endif
-	if (end_string == NULL)
+	if (end_string == NULL) {
 		end_string =  g_strrstr (filename, ".gz");
+	}
 
 	if (end_string) {
 		len = end_string - filename;
@@ -118,13 +122,18 @@ yelp_man_populate_tree_for_subdir (GHashTable *section_hash,
 				   char secnum)
 {
 	DIR *dirh;
-	struct dirent *dent;
-	char uribuf[128], titlebuf[128];
+	struct dirent   *dent;
+	char             uribuf[128], titlebuf[128];
 	struct TreeNode *node;
-
+	YelpSection     *yelp_section;
+	YelpSection     *index_section;
+	gchar           *index_name;
+	gchar           *index_uri;
+	
 	dirh = opendir (basedir);
-	if (!dirh)
+	if (!dirh) {
 		return;
+	}
 
 	readdir (dirh);		/* skip . & .. */
 	readdir (dirh);
@@ -134,12 +143,14 @@ yelp_man_populate_tree_for_subdir (GHashTable *section_hash,
 		char *manname;
 		char *filename;
 
-		if (dent->d_name[0] == '.')
+		if (dent->d_name[0] == '.') {
 			continue;
+		}
 
 		section = extract_secnum_from_filename (dent->d_name);
-		if (!section)
+		if (!section) {
 			continue;
+		}
 
 		if (section[0] != secnum) {
 			g_free (section);
@@ -149,10 +160,14 @@ yelp_man_populate_tree_for_subdir (GHashTable *section_hash,
 		manname = man_name_without_suffix (dent->d_name);
 		filename = g_build_filename (basedir, dent->d_name, NULL);
 
-		g_snprintf (titlebuf, sizeof (titlebuf), "%s (%s)", manname, section);
-		g_snprintf (uribuf, sizeof (uribuf), "man:%s", filename);
+		g_snprintf (titlebuf, sizeof (titlebuf), "%s (%s)", 
+			    manname, section);
+
+		g_snprintf (uribuf, sizeof (uribuf), "man:%s.%s", 
+			    manname, section);
 
 		node = g_hash_table_lookup (section_hash, section);
+
 		if (node == NULL) {
 			char buf[2];
 			buf[0] = secnum; buf[1] = 0;
@@ -162,10 +177,26 @@ yelp_man_populate_tree_for_subdir (GHashTable *section_hash,
 
 		g_assert (node != NULL);
 		
-		node->pages = g_list_prepend (node->pages, 
-					      yelp_section_new (YELP_SECTION_DOCUMENT,
-								titlebuf, uribuf, 
-								NULL, NULL));
+		any_man_pages = TRUE;
+		
+		yelp_section = yelp_section_new (YELP_SECTION_DOCUMENT,
+						 titlebuf, uribuf, 
+						 NULL, NULL);
+
+		node->pages = g_list_prepend (node->pages, yelp_section);
+
+		index_name = g_ascii_strdown (titlebuf, -1);
+		index_uri = g_strconcat ("index:", uribuf, NULL);
+
+		index_section = yelp_section_new (YELP_SECTION_INDEX,
+						  index_name, index_uri,
+						  yelp_section->reference,
+						  yelp_section->scheme);
+		g_free (index_name);
+		g_free (index_uri);
+
+		man_index = g_list_prepend (man_index, index_section);
+					
 		g_free (manname);
 		g_free (section);
 		g_free (filename);
@@ -491,11 +522,14 @@ yelp_man_cleanup_initial_tree (struct TreeNode *node)
 		child = l->data;
 		l = l->next;
 		
-		if (child->pages == NULL && child->tree_nodes == NULL)
-			node->tree_nodes = g_list_remove (node->tree_nodes, child);
+		if (child->pages == NULL && child->tree_nodes == NULL) {
+			node->tree_nodes = g_list_remove (node->tree_nodes, 
+							  child);
+		}
+		
 	}
 
-	node->pages = g_list_sort (node->pages, (GCompareFunc)yelp_section_compare);
+	node->pages = g_list_sort (node->pages, yelp_section_compare);
 }
 
 static void
@@ -540,7 +574,7 @@ yelp_man_push_initial_tree (struct TreeNode *node, GNode *parent)
 }
 
 gboolean
-yelp_man_init (GNode *tree)
+yelp_man_init (GNode *tree, GList **index)
 {
 	gchar            *manpath = NULL;
  	char            **manpathes = NULL;
@@ -589,10 +623,16 @@ yelp_man_init (GNode *tree)
 
 	yelp_man_cleanup_initial_tree (root);
 	
+	if (!any_man_pages) {
+		return FALSE;
+	}
+
 	yelp_man_push_initial_tree (root, tree);
 	
 	yelp_man_free_initial_tree (root);
 	g_hash_table_destroy (section_hash);
+
+	*index = g_list_concat (*index, man_index);
 	
 	return TRUE;
 }
