@@ -26,6 +26,10 @@
 
 #include <libgnome/gnome-i18n.h>
 #include <gtk/gtktreeview.h>
+#include <gtk/gtktreeselection.h>
+#include <gtk/gtkscrolledwindow.h>
+#include <gtk/gtkcellrenderertext.h>
+#include <gtk/gtkframe.h>
 
 #include <string.h>
 
@@ -57,7 +61,7 @@ struct _YelpViewContentPriv {
 	GNode        *doc_tree;
 
 	/* Html view */
-	GtkWidget    *html_view;
+	YelpHtml     *html_view;
 
 	gchar        *current_docpath;
 };
@@ -162,11 +166,10 @@ yvc_tree_selection_changed_cb (GtkTreeSelection *selection,
 	if (gtk_tree_selection_get_selected (selection, NULL, &iter)) {
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->content_tree));
 		
-		gtk_tree_model_get (model, &iter, 
+		gtk_tree_model_get (model, &iter,
 				    1, &section,
 				    -1);
 
-/* 		yelp_html_open_section (YELP_HTML (priv->html_view), section); */
  		g_signal_emit (content, signals[URL_SELECTED], 0,
  			       section->reference, section->uri, FALSE);
 	}
@@ -213,10 +216,11 @@ yelp_view_content_new (GNode *doc_tree)
                                         GTK_POLICY_AUTOMATIC,
                                         GTK_POLICY_AUTOMATIC);
 	frame = gtk_frame_new (NULL);
-	gtk_container_add (GTK_CONTAINER (frame), html_sw);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
 	
-        gtk_container_add (GTK_CONTAINER (html_sw), priv->html_view);
+	gtk_container_add (GTK_CONTAINER (frame), html_sw);
+        gtk_container_add (GTK_CONTAINER (html_sw), 
+			   yelp_html_get_widget (priv->html_view));
 
 	/* Add the tree and html view to the paned */
 	gtk_paned_add1 (GTK_PANED (view), priv->tree_sw);
@@ -274,12 +278,14 @@ yelp_view_content_set_tree (YelpViewContent *content,
 }
 
 void
-yelp_view_content_show_uri (YelpViewContent *content,
-			    const gchar     *url)
+yelp_view_content_show_uri (YelpViewContent  *content,
+			    const gchar      *url,
+			    GError          **error)
 {
 	YelpViewContentPriv *priv;
 	gchar               *content_url;
 	GNode               *node;
+	gchar               *section = NULL;
 	
 	g_return_if_fail (YELP_IS_VIEW_CONTENT (content));
 	g_return_if_fail (url != NULL);
@@ -303,7 +309,7 @@ yelp_view_content_show_uri (YelpViewContent *content,
 	} else if (strncmp (url, "ghelp:", 6) == 0) {
 		/* ghelp uri-scheme /usr/share/gnome/help... */
 		gchar *docpath;
-		
+
  		docpath = yelp_util_extract_docpath_from_uri (url);
 
 		if (docpath && strcmp (docpath, priv->current_docpath)) {
@@ -312,9 +318,9 @@ yelp_view_content_show_uri (YelpViewContent *content,
 			node = yelp_scrollkeeper_get_toc_tree (docpath);
 			
 			if (node) {
+				gtk_widget_show (priv->tree_sw);
 				yelp_view_content_set_tree (content, node);
 				
-				gtk_widget_show (priv->tree_sw);
 			} else {
 				gtk_widget_hide (priv->tree_sw);
 			}
@@ -322,10 +328,11 @@ yelp_view_content_show_uri (YelpViewContent *content,
 			g_free (priv->current_docpath);
 			priv->current_docpath = g_strdup (docpath);
 		}
-		
+
 		g_free (docpath);
 
-		content_url = (char *) url;
+		content_url = yelp_util_split_uri (url, &section);
+		
 	} else if (!strncmp (url, "info:", 5) || !strncmp (url, "man:", 4)) {
 		node = yelp_util_find_node_from_uri (priv->doc_tree, url);
 
@@ -338,10 +345,17 @@ yelp_view_content_show_uri (YelpViewContent *content,
 		content_url = (char *) url;
 	}
 
-	yelp_html_open_uri (YELP_HTML (priv->html_view), 
-			    content_url, NULL);
+	yelp_html_open_uri (priv->html_view, content_url, section, error);
 
 	if (content_url != url) {
 		g_free (content_url);
 	}
 }
+
+void
+yelp_view_content_stop (YelpViewContent *content)
+{
+	g_return_if_fail (YELP_IS_VIEW_CONTENT (content));
+	
+	yelp_html_cancel_loading (content->priv->html_view);
+}
